==> corestuff-2.7.0.tar.gz: corestuff-v2.7.0/activities/pageactivites.h <==
/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once

#include <QWidget>

#include "global.h"

class QToolButton;
class QTreeWidgetItem;

namespace Ui {
    class pageactivites;
}

class pageactivites : public QWidget {
    Q_OBJECT

public:
    explicit pageactivites(QWidget *parent = nullptr);
    ~pageactivites();

    void reload();
    void addControls(QList<QToolButton*> controls);
    void clearActivities();

private slots:
    void on_activitesView_itemSelectionChanged();

private:
    Ui::pageactivites *ui;
    QToolButton       *menu = nullptr;
    QToolButton       *m_clearActivities = nullptr;
    QSize             listViewIconSize;
    bool              touch, showRecent;

    void loadSettings();
    void startSetup();
    void setupActivitesView();

    void clearActivites();
    void openSelectedActivites(QTreeWidgetItem *item, int column);

};

==> corestuff-4.1.0.tar.gz: corestuff-v4.1.0/activities/pageactivites.h <==
/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once

#include <QWidget>

#include "global.h"

class QToolButton;
class QTreeWidgetItem;

namespace Ui {
    class pageactivites;
}

class pageactivites : public QWidget {
    Q_OBJECT

public:
    explicit pageactivites(QWidget *parent = nullptr);
    ~pageactivites();

    void reload();
    void addControls(QList<QToolButton*> controls);
    void clearActivities();

private slots:
    void on_activitesView_itemSelectionChanged();

private:
    Ui::pageactivites *ui;
    QToolButton       *menu = nullptr;
    QToolButton       *m_clearActivities = nullptr;
    QSize             listViewIconSize;
    bool              touch, showActivities;

    void loadSettings();
    void startSetup();
    void setupActivitesView();

    void clearActivites();
    void openSelectedActivites(QTreeWidgetItem *item, int column);

};
